@@ -8,7 +8,7 @@ from __future__ import annotations
 
 # Standard imports
 from dataclasses import dataclass, field
-from typing import Any, Callable, Dict, List, Tuple, cast
+from typing import Any, Callable, Dict, List, cast
 
 # Third party imports
 from dotmap import DotMap
@@ -48,7 +48,13 @@ from ..utils.classes.magicdotpath import (
     LambdaMagicDotPathAggregate,
     MagicDotPath,
 )
-from ..utils.classes.other_classes import Command, Flags, SQLEnumerableData, equality
+from ..utils.classes.other_classes import (
+    Command,
+    Flags,
+    PyLinqSqlInsertType,
+    SQLEnumerableData,
+    equality,
+)
 from ..utils.db import get_cursor
 from ..utils.execute import execute_alter, execute_one, execute_select
 from ..utils.functions.other_functions import safe
@@ -466,7 +472,7 @@ class SQLEnumerable:
     def insert(
         self,
         column: List[str] | str,
-        data: Dict[str, Any] | List[Dict[str, Any]] | Tuple | List[Tuple],
+        data: PyLinqSqlInsertType,
     ) -> SQLEnumerable:
         """
         Add an INSERT command to the command list.
